// Import required modules
const express = require('express');
const mongoose = require('mongoose');
const cors = require('cors');

// Initialize Express app
const app = express();
const PORT = 3000; // Define the port the server will run on

// Middleware setup
app.use(express.json()); // Parse incoming JSON requests
app.use(cors()); // Enable Cross-Origin Resource Sharing

// Connect to MongoDB database
mongoose.connect('mongodb://localhost:27017/todo-app', {
    useNewUrlParser: true,
    useUnifiedTopology: true,
});

// Define the schema for a TODO item
const todoSchema = new mongoose.Schema({
    text: String, // The text of the TODO item
    done: Boolean, // Whether the TODO item is marked as done
});

// Create a model for the TODO items
const Todo = mongoose.model('Todo', todoSchema);

// Define API routes

// Get all TODO items
app.get('/todos', async (req, res) => {
    const todos = await Todo.find(); // Fetch all TODO items from the database
    res.json(todos); // Return the TODO items as JSON
});

// Add a new TODO item
app.post('/todos', async (req, res) => {
    const newTodo = new Todo({
        text: req.body.text, // Text of the new TODO item
        done: false, // Default to not done
    });
    await newTodo.save(); // Save the new TODO item to the database
    res.json(newTodo); // Return the newly created TODO item
});

// Update a TODO item (mark as done/undone)
app.put('/todos/:id', async (req, res) => {
    const updatedTodo = await Todo.findByIdAndUpdate(
        req.params.id, // ID of the TODO item to update
        { done: req.body.done }, // Update the 'done' status
        { new: true } // Return the updated document
    );
    res.json(updatedTodo); // Return the updated TODO item
});

// Delete a TODO item
app.delete('/todos/:id', async (req, res) => {
    await Todo.findByIdAndDelete(req.params.id); // Delete the TODO item by ID
    res.json({ message: 'Todo deleted' }); // Return a success message
});

// Start the server
app.listen(PORT, () => {
    console.log(`Server running on http://localhost:${PORT}`); // Log the server URL
});